summaryrefslogtreecommitdiff
path: root/sys/net
diff options
context:
space:
mode:
authorBret Lambert <blambert@cvs.openbsd.org>2012-09-20 10:25:04 +0000
committerBret Lambert <blambert@cvs.openbsd.org>2012-09-20 10:25:04 +0000
commit1d93dff49c1685e4199f27d3a3c64672a1cfed12 (patch)
tree7af3f3812583f81df1d725378b289ab17d3ac08a /sys/net
parent34d8a7bba54c1f5e801c3c50bef8188e2ad89fe8 (diff)
spltdb() was really just #define'd to be splsoftnet(); replace the former
with the latter no change in md5 checksum of generated files ok claudio@ henning@
Diffstat (limited to 'sys/net')
-rw-r--r--sys/net/if_bridge.c4
-rw-r--r--sys/net/if_pfsync.c4
-rw-r--r--sys/net/pfkey.c4
-rw-r--r--sys/net/pfkeyv2.c26
4 files changed, 19 insertions, 19 deletions
diff --git a/sys/net/if_bridge.c b/sys/net/if_bridge.c
index 1d81886b002..052cd6c626e 100644
--- a/sys/net/if_bridge.c
+++ b/sys/net/if_bridge.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: if_bridge.c,v 1.194 2012/07/16 18:05:36 markus Exp $ */
+/* $OpenBSD: if_bridge.c,v 1.195 2012/09/20 10:25:03 blambert Exp $ */
/*
* Copyright (c) 1999, 2000 Jason L. Wright (jason@thought.net)
@@ -2395,7 +2395,7 @@ bridge_ipsec(struct bridge_softc *sc, struct ifnet *ifp,
if (proto == 0)
goto skiplookup;
- s = spltdb();
+ s = splsoftnet();
tdb = gettdb(ifp->if_rdomain, spi, &dst, proto);
if (tdb != NULL && (tdb->tdb_flags & TDBF_INVALID) == 0 &&
diff --git a/sys/net/if_pfsync.c b/sys/net/if_pfsync.c
index 6e9b3e82e41..773e2b7ca97 100644
--- a/sys/net/if_pfsync.c
+++ b/sys/net/if_pfsync.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: if_pfsync.c,v 1.190 2012/09/19 13:47:17 mikeb Exp $ */
+/* $OpenBSD: if_pfsync.c,v 1.191 2012/09/20 10:25:03 blambert Exp $ */
/*
* Copyright (c) 2002 Michael Shalayeff
@@ -1207,7 +1207,7 @@ pfsync_update_net_tdb(struct pfsync_tdb *pt)
pt->dst.sa.sa_family != AF_INET6))
goto bad;
- s = spltdb();
+ s = splsoftnet();
tdb = gettdb(ntohs(pt->rdomain), pt->spi, &pt->dst, pt->sproto);
if (tdb) {
pt->rpl = betoh64(pt->rpl);
diff --git a/sys/net/pfkey.c b/sys/net/pfkey.c
index f80e0971966..361d819934a 100644
--- a/sys/net/pfkey.c
+++ b/sys/net/pfkey.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: pfkey.c,v 1.18 2008/05/23 15:51:12 thib Exp $ */
+/* $OpenBSD: pfkey.c,v 1.19 2012/09/20 10:25:03 blambert Exp $ */
/*
* @(#)COPYRIGHT 1.1 (NRL) 17 January 1995
@@ -147,7 +147,7 @@ pfkey_sendup(struct socket *socket, struct mbuf *packet, int more)
} else
packet2 = packet;
- s = spltdb();
+ s = splsoftnet();
if (!sbappendaddr(&socket->so_rcv, &pfkey_addr, packet2, NULL)) {
m_freem(packet2);
splx(s);
diff --git a/sys/net/pfkeyv2.c b/sys/net/pfkeyv2.c
index e52b05986cb..a3f35a5c3c1 100644
--- a/sys/net/pfkeyv2.c
+++ b/sys/net/pfkeyv2.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: pfkeyv2.c,v 1.125 2012/03/28 19:43:21 claudio Exp $ */
+/* $OpenBSD: pfkeyv2.c,v 1.126 2012/09/20 10:25:03 blambert Exp $ */
/*
* @(#)COPYRIGHT 1.1 (NRL) 17 January 1995
@@ -1002,7 +1002,7 @@ pfkeyv2_send(struct socket *socket, void *message, int len)
}
#endif /* IPSEC */
- s = spltdb();
+ s = splsoftnet();
/* Find TDB */
sa2 = gettdb(rdomain, ssa->sadb_sa_spi, sunionp,
@@ -1165,7 +1165,7 @@ pfkeyv2_send(struct socket *socket, void *message, int len)
}
#endif /* IPSEC */
- s = spltdb();
+ s = splsoftnet();
sa2 = gettdb(rdomain, ssa->sadb_sa_spi, sunionp,
SADB_X_GETSPROTO(smsg->sadb_msg_satype));
@@ -1278,7 +1278,7 @@ pfkeyv2_send(struct socket *socket, void *message, int len)
sunionp =
(union sockaddr_union *)(headers[SADB_EXT_ADDRESS_DST] +
sizeof(struct sadb_address));
- s = spltdb();
+ s = splsoftnet();
sa2 = gettdb(rdomain, ssa->sadb_sa_spi, sunionp,
SADB_X_GETSPROTO(smsg->sadb_msg_satype));
@@ -1314,7 +1314,7 @@ pfkeyv2_send(struct socket *socket, void *message, int len)
(union sockaddr_union *)(headers[SADB_EXT_ADDRESS_DST] +
sizeof(struct sadb_address));
- s = spltdb();
+ s = splsoftnet();
sa2 = gettdb(rdomain, ssa->sadb_sa_spi, sunionp,
SADB_X_GETSPROTO(smsg->sadb_msg_satype));
@@ -1407,7 +1407,7 @@ pfkeyv2_send(struct socket *socket, void *message, int len)
switch (smsg->sadb_msg_satype) {
case SADB_SATYPE_UNSPEC:
- s = spltdb();
+ s = splsoftnet();
/*
* Go through the list of policies, delete those that
@@ -1429,7 +1429,7 @@ pfkeyv2_send(struct socket *socket, void *message, int len)
#ifdef TCP_SIGNATURE
case SADB_X_SATYPE_TCPSIGNATURE:
#endif /* TCP_SIGNATURE */
- s = spltdb();
+ s = splsoftnet();
tdb_walk(rdomain, pfkeyv2_flush_walker,
(u_int8_t *) &(smsg->sadb_msg_satype));
@@ -1449,7 +1449,7 @@ pfkeyv2_send(struct socket *socket, void *message, int len)
dump_state.sadb_msg = (struct sadb_msg *) headers[0];
dump_state.socket = socket;
- s = spltdb();
+ s = splsoftnet();
rval = tdb_walk(rdomain, pfkeyv2_dump_walker, &dump_state);
splx(s);
@@ -1470,7 +1470,7 @@ pfkeyv2_send(struct socket *socket, void *message, int len)
sunionp = (union sockaddr_union *) (headers[SADB_EXT_ADDRESS_DST] +
sizeof(struct sadb_address));
- s = spltdb();
+ s = splsoftnet();
tdb1 = gettdb(rdomain, ssa->sadb_sa_spi, sunionp,
SADB_X_GETSPROTO(smsg->sadb_msg_satype));
@@ -1561,7 +1561,7 @@ pfkeyv2_send(struct socket *socket, void *message, int len)
bzero(&re, sizeof(struct route_enc));
bcopy(&encapdst, &re.re_dst, sizeof(struct sockaddr_encap));
- s = spltdb();
+ s = splsoftnet();
/* Set the rdomain that was obtained from the socket */
re.re_tableid = rdomain;
@@ -2432,7 +2432,7 @@ ret:
}
/*
* Caller is responsible for setting at least spltdb().
*/
int
pfkeyv2_ipo_walk(u_int rdomain, int (*walker)(struct ipsec_policy *, void *),
@@ -2535,7 +2535,7 @@ pfkeyv2_sysctl(int *name, u_int namelen, void *oldp, size_t *oldlenp,
case NET_KEY_SADB_DUMP:
if ((error = suser(curproc, 0)) != 0)
return (error);
- s = spltdb();
+ s = splsoftnet();
error = tdb_walk(rdomain, pfkeyv2_sysctl_walker, &w);
splx(s);
if (oldp)
@@ -2545,7 +2545,7 @@ pfkeyv2_sysctl(int *name, u_int namelen, void *oldp, size_t *oldlenp,
break;
case NET_KEY_SPD_DUMP:
- s = spltdb();
+ s = splsoftnet();
error = pfkeyv2_ipo_walk(rdomain,
pfkeyv2_sysctl_policydumper, &w);
splx(s);
@@ -2432,7 +2432,7 @@ ret:
}
/*
- * Caller is responsible for setting at least spltdb().
+ * Caller is responsible for setting at least splsoftnet().
*/
int